@@ -1,6 +1,7 @@
 from os.path import isfile
 
-from pytezos import Contract, pytezos
+from pytezos import Contract
+from pytezos.interop import Interop
 from pytezos.encoding import is_kt
 from pytezos.repl.control import instruction, do_interpret
 from pytezos.repl.context import Context
@@ -150,9 +151,9 @@ def do_include(ctx: Context, prim, args, annots):
         network = parts[0] if len(parts) > 1 else ctx.get('NETWORK', 'mainnet')
         address = parts[1] if len(parts) > 1 else parts[0]
         assert is_kt(address), f'expected filename or KT address (with network), got {path}'
-        code = pytezos.using(network).contract(address).contract.code
-        storage = pytezos.using(network).shell.contracts[address].storage()
-        ctx.set('STORAGE', storage)
+        script = Interop().using(network).shell.contracts[address].script()
+        code = script['code']
+        ctx.set('STORAGE', script['storage'])
 
     do_interpret(ctx, code)
 
@@ -177,7 +178,7 @@ def do_reset(ctx: Context, prim, args, annots):
     network = get_string(args[0])
     assert network in networks, f'expected on of {", ".join(networks)}, got {network}'
     ctx.set('NETWORK', network)
-    chain_id = ChainID(pytezos.using(network).shell.chains.main.chain_id())
+    chain_id = ChainID(Interop().using(network).shell.chains.main.chain_id())
     ctx.set('CHAIN_ID', chain_id)
     ctx.big_maps.reset()
     ctx.drop_all()
